summary refs log tree commit diff
path: root/io/sys/sendfile.h
diff options
context:
space:
mode:
Diffstat (limited to 'io/sys/sendfile.h')
-rw-r--r--io/sys/sendfile.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/io/sys/sendfile.h b/io/sys/sendfile.h
index 0627c40464..797822b9fe 100644
--- a/io/sys/sendfile.h
+++ b/io/sys/sendfile.h
@@ -25,8 +25,11 @@
 
 __BEGIN_DECLS
 
-/* Send COUNT bytes from file associated with IN_FD starting at OFFSET to
-   descriptor OUT_FD.  */
+/* Send up to COUNT bytes from file associated with IN_FD starting at
+   *OFFSET to descriptor OUT_FD.  Set *OFFSET to the IN_FD's file position
+   following the read bytes.  If OFFSET is a null pointer, use the normal
+   file position instead.  Return the number of written bytes, or -1 in
+   case of error.  */
 #ifndef __USE_FILE_OFFSET64
 extern ssize_t sendfile (int __out_fd, int __in_fd, off_t *__offset,
 			 size_t __count) __THROW;